==> haskell-ptr-0.16.8.7-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ptr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ptr
version:              0.16.8.7
visibility:           public
id:                   ptr-0.16.8.7-4Ie3Sz1M4jTHckcL2yrDKt
key:                  ptr-0.16.8.7-4Ie3Sz1M4jTHckcL2yrDKt
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/ptr
synopsis:             Experimental abstractions for operations on pointers
description:
    Collection of experimental abstractions over pointer operations.

category:             Ptr, Data
abi:                  9541801b9e199be29546981a59e9f31e
exposed:              True
exposed-modules:
    Ptr.ByteString Ptr.IO Ptr.Parse Ptr.ParseUnbound Ptr.Peek Ptr.Poke
    Ptr.PokeAndPeek Ptr.Poking Ptr.Read Ptr.Receive

hidden-modules:
    Ptr.List Ptr.PokeIO Ptr.Prelude Ptr.Receive.Core
    Ptr.UncheckedShifting Ptr.Util.ByteString Ptr.Util.Word8Predicates

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ptr
hs-libraries:         HSptr-0.16.8.7-4Ie3Sz1M4jTHckcL2yrDKt
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    profunctors-5.6.3-1rS3FBb1Nud9uOnEvo2O4l
    strict-list-0.1.7.6-4WaDCcLnTxcAqkpEV226GF text-2.0.2 time-1.12.2
    vector-0.13.2.0-F8322NeNtfL69paM3N9AVt

haddock-interfaces:   /usr/share/doc/haskell-ptr/html/ptr.haddock
haddock-html:         /usr/share/doc/haskell-ptr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ptr-0.16.8.7-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ptr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ptr
version:              0.16.8.7
visibility:           public
id:                   ptr-0.16.8.7-94PtQtt9ufBI8Z1E15qJK8
key:                  ptr-0.16.8.7-94PtQtt9ufBI8Z1E15qJK8
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/ptr
synopsis:             Experimental abstractions for operations on pointers
description:
    Collection of experimental abstractions over pointer operations.

category:             Ptr, Data
abi:                  eace06ae125743e2324005e5864091f4
exposed:              True
exposed-modules:
    Ptr.ByteString Ptr.IO Ptr.Parse Ptr.ParseUnbound Ptr.Peek Ptr.Poke
    Ptr.PokeAndPeek Ptr.Poking Ptr.Read Ptr.Receive

hidden-modules:
    Ptr.List Ptr.PokeIO Ptr.Prelude Ptr.Receive.Core
    Ptr.UncheckedShifting Ptr.Util.ByteString Ptr.Util.Word8Predicates

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ptr
hs-libraries:         HSptr-0.16.8.7-94PtQtt9ufBI8Z1E15qJK8
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    profunctors-5.6.3-IrIOzlkE4qyKAowsmKVLhe
    strict-list-0.1.7.6-D97mY6PgL944jayzt2Bfno text-2.0.2 time-1.12.2
    vector-0.13.2.0-F8322NeNtfL69paM3N9AVt

haddock-interfaces:   /usr/share/doc/haskell-ptr/html/ptr.haddock
haddock-html:         /usr/share/doc/haskell-ptr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
